from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="SendNotification")


@attr.s(auto_attribs=True)
class SendNotification:
    """
    Attributes:
        body (str):
        name (str):  Example: action-name.
        title (str):
    """

    body: str
    name: str
    title: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        body = self.body
        name = self.name
        title = self.title

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "body": body,
                "name": name,
                "title": title,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        body = d.pop("body")

        name = d.pop("name")

        title = d.pop("title")

        send_notification = cls(
            body=body,
            name=name,
            title=title,
        )

        send_notification.additional_properties = d
        return send_notification

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
